==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Input/ffap/translations/ffap_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>FFap プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Monkey&apos;s Audio ファイル</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation>FFap 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>QMMP FFap 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>このプラグインは Monkey&apos;s Audio (APE) をサポートします</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>deadbeef と FFmpeg と rockbox のコードを基に作成</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="65"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="66"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-2.3.0.tar.bz2: qmmp-plugin-pack-2.3.0/src/Input/ffap/translations/ffap_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>FFap プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Monkey&apos;s Audio ファイル</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation>FFap 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>QMMP FFap 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>このプラグインは Monkey&apos;s Audio (APE) をサポートします</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>deadbeef と FFmpeg と rockbox のコードを基に作成</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Samples</source>
        <translation>サンプル</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Version</source>
        <translation>版</translation>
    </message>
</context>
</TS>
